Usage accounting, limits, and optional pricing primitives for Starweaver.
Structs
- Pricing
Estimate - Estimated USD pricing for usage.
- Usage
- Token and request usage accumulated by model and runtime layers.
- Usage
Agent Total - Cumulative usage grouped by agent/source.
- Usage
Limits - Runtime usage limits for one agent run.
- Usage
Snapshot - Cumulative usage snapshot for one run.
- Usage
Snapshot Entry - Cumulative usage for one agent or usage source in the current run.
Enums
- Usage
Limit Error - Usage limit error.
- Usage
Token Kind - Token counter checked by a usage limit.
Functions
- add_
optional_ pricing - Aggregate an optional pricing estimate into a running total.