Crate starweaver_usage

Crate starweaver_usage 

Usage accounting, limits, and optional pricing primitives for Starweaver.

Structs

PricingEstimate
Estimated USD pricing for usage.
Usage
Token and request usage accumulated by model and runtime layers.
UsageAgentTotal
Cumulative usage grouped by agent/source.
UsageLimits
Runtime usage limits for one agent run.
UsageSnapshot
Cumulative usage snapshot for one run.
UsageSnapshotEntry
Cumulative usage for one agent or usage source in the current run.

Enums

UsageLimitError
Usage limit error.
UsageTokenKind
Token counter checked by a usage limit.

Functions

add_optional_pricing
Aggregate an optional pricing estimate into a running total.