pub struct Usage {
pub requests: u64,
pub input_tokens: u64,
pub cache_write_tokens: u64,
pub cache_read_tokens: u64,
pub output_tokens: u64,
pub total_tokens: u64,
pub tool_calls: u64,
}Expand description
Token and request usage accumulated by model and runtime layers.
Fields
requests: u64Number of provider requests.
input_tokens: u64Input or prompt tokens.
Provider adapters should normalize this as total provider-billed input tokens for the request, including cache-write and cache-read tokens when those subtotals are present. Pricing helpers subtract the cache subtotals before applying cache-specific rates.
cache_write_tokens: u64Tokens written to a provider prompt cache.
cache_read_tokens: u64Tokens read from a provider prompt cache.
output_tokens: u64Output or completion tokens.
total_tokens: u64Total tokens.
tool_calls: u64Number of successful function tool calls executed by the runtime.
Implementations
Sourceimpl Usage
impl Usage
Sourcepub fn add_assign(&mut self, other: &Self)
pub fn add_assign(&mut self, other: &Self)
Add another usage value into this one.
Sourcepub const fn with_additional_tool_calls(self, tool_calls: u64) -> Self
pub const fn with_additional_tool_calls(self, tool_calls: u64) -> Self
Return a copy with additional successful tool calls applied.